@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2009 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002 Vincent Richard <vincent@vmime.org>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -30,15 +30,13 @@
 #include "vmime/text.hpp"
 
 
-namespace vmime
-{
+namespace vmime {
 
 
 /** A group of mailboxes (basic type).
   */
+class VMIME_EXPORT mailboxGroup : public address {
 
-class mailboxGroup : public address
-{
 public:
 
 	mailboxGroup();
@@ -49,10 +47,10 @@ public:
 
 
 	void copyFrom(const component& other);
-	ref <component> clone() const;
+	shared_ptr <component> clone() const;
 	mailboxGroup& operator=(const component& other);
 
-	const std::vector <ref <const component> > getChildComponents() const;
+	const std::vector <shared_ptr <component> > getChildComponents();
 
 	/** Return the name of the group.
 	  *
@@ -70,51 +68,66 @@ public:
 	  *
 	  * @param mbox mailbox to append
 	  */
-	void appendMailbox(ref <mailbox> mbox);
+	void appendMailbox(const shared_ptr <mailbox>& mbox);
 
 	/** Insert a new mailbox before the specified mailbox.
 	  *
 	  * @param beforeMailbox mailbox before which the new mailbox will be inserted
 	  * @param mbox mailbox to insert
-	  * @throw exceptions::no_such_mailbox if the mailbox is not in the list
+	  * @throw std::out_of_range if the mailbox is not in the list
 	  */
-	void insertMailboxBefore(ref <mailbox> beforeMailbox, ref <mailbox> mbox);
+	void insertMailboxBefore(
+		const shared_ptr <mailbox>& beforeMailbox,
+		const shared_ptr <mailbox>& mbox
+	);
 
 	/** Insert a new mailbox before the specified position.
 	  *
 	  * @param pos position at which to insert the new mailbox (0 to insert at
 	  * the beginning of the list)
 	  * @param mbox mailbox to insert
+	  * @throw std::out_of_range if the position is out of range
 	  */
-	void insertMailboxBefore(const int pos, ref <mailbox> mbox);
+	void insertMailboxBefore(
+		const size_t pos,
+		const shared_ptr <mailbox>& mbox
+	);
 
 	/** Insert a new mailbox after the specified mailbox.
 	  *
 	  * @param afterMailbox mailbox after which the new mailbox will be inserted
 	  * @param mbox mailbox to insert
-	  * @throw exceptions::no_such_mailbox if the mailbox is not in the list
+	  * @throw std::out_of_range if the mailbox is not in the list
 	  */
-	void insertMailboxAfter(ref <mailbox> afterMailbox, ref <mailbox> mbox);
+	void insertMailboxAfter(
+		const shared_ptr <mailbox>& afterMailbox,
+		const shared_ptr <mailbox>& mbox
+	);
 
 	/** Insert a new mailbox after the specified position.
 	  *
 	  * @param pos position of the mailbox before the new mailbox
 	  * @param mbox mailbox to insert
+	  * @throw std::out_of_range if the position is out of range
 	  */
-	void insertMailboxAfter(const int pos, ref <mailbox> mbox);
+	void insertMailboxAfter(
+		const size_t pos,
+		const shared_ptr <mailbox>& mbox
+	);
 
 	/** Remove the specified mailbox from the list.
 	  *
 	  * @param mbox mailbox to remove
-	  * @throw exceptions::no_such_mailbox if the mailbox is not in the list
+	  * @throw std::out_of_range if the mailbox is not in the list
 	  */
-	void removeMailbox(ref <mailbox> mbox);
+	void removeMailbox(const shared_ptr <mailbox>& mbox);
 
 	/** Remove the mailbox at the specified position.
 	  *
 	  * @param pos position of the mailbox to remove
+	  * @throw std::out_of_range if the position is out of range
 	  */
-	void removeMailbox(const int pos);
+	void removeMailbox(const size_t pos);
 
 	/** Remove all mailboxes from the list.
 	  */
@@ -124,7 +137,7 @@ public:
 	  *
 	  * @return number of mailboxes
 	  */
-	int getMailboxCount() const;
+	size_t getMailboxCount() const;
 
 	/** Tests whether the list of mailboxes is empty.
 	  *
@@ -136,43 +149,54 @@ public:
 	  *
 	  * @param pos position
 	  * @return mailbox at position 'pos'
+	  * @throw std::out_of_range if the position is out of range
 	  */
-	ref <mailbox> getMailboxAt(const int pos);
+	shared_ptr <mailbox> getMailboxAt(const size_t pos);
 
 	/** Return the mailbox at the specified position.
 	  *
 	  * @param pos position
 	  * @return mailbox at position 'pos'
+	  * @throw std::out_of_range if the position is out of range
 	  */
-	const ref <const mailbox> getMailboxAt(const int pos) const;
+	const shared_ptr <const mailbox> getMailboxAt(const size_t pos) const;
 
 	/** Return the mailbox list.
 	  *
 	  * @return list of mailboxes
 	  */
-	const std::vector <ref <const mailbox> > getMailboxList() const;
+	const std::vector <shared_ptr <const mailbox> > getMailboxList() const;
 
 	/** Return the mailbox list.
 	  *
 	  * @return list of mailboxes
 	  */
-	const std::vector <ref <mailbox> > getMailboxList();
+	const std::vector <shared_ptr <mailbox> > getMailboxList();
 
 	bool isGroup() const;
 
 private:
 
 	text m_name;
-	std::vector <ref <mailbox> > m_list;
+	std::vector <shared_ptr <mailbox> > m_list;
 
-public:
-
-	using address::parse;
-	using address::generate;
+protected:
 
 	// Component parsing & assembling
-	void parse(const string& buffer, const string::size_type position, const string::size_type end, string::size_type* newPosition = NULL);
-	void generate(utility::outputStream& os, const string::size_type maxLineLength = lineLengthLimits::infinite, const string::size_type curLinePos = 0, string::size_type* newLinePos = NULL) const;
+	void parseImpl(
+		const parsingContext& ctx,
+		const string& buffer,
+		const size_t position,
+		const size_t end,
+		size_t* newPosition = NULL
+	);
+
+	void generateImpl(
+		const generationContext& ctx,
+		utility::outputStream& os,
+		const size_t curLinePos = 0,
+		size_t* newLinePos = NULL
+	) const;
 };
 
 
