@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2009 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002 Vincent Richard <vincent@vmime.org>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -27,8 +27,13 @@
 
 #include "vmime/config.hpp"
 
+
+#if VMIME_HAVE_MESSAGING_FEATURES && VMIME_HAVE_MESSAGING_PROTO_IMAP
+
+
 #include "vmime/net/socket.hpp"
 #include "vmime/net/timeoutHandler.hpp"
+#include "vmime/net/tracer.hpp"
 #include "vmime/net/session.hpp"
 #include "vmime/net/connectionInfos.hpp"
 
@@ -44,13 +49,14 @@ namespace imap {
 
 class IMAPTag;
 class IMAPStore;
+class IMAPCommand;
 
 
-class IMAPConnection : public object
-{
+class VMIME_EXPORT IMAPConnection : public object, public enable_shared_from_this <IMAPConnection> {
+
 public:
 
-	IMAPConnection(ref <IMAPStore> store, ref <security::authenticator> auth);
+	IMAPConnection(const shared_ptr <IMAPStore>& store, const shared_ptr <security::authenticator>& auth);
 	~IMAPConnection();
 
 
@@ -59,8 +65,7 @@ public:
 	void disconnect();
 
 
-	enum ProtocolStates
-	{
+	enum ProtocolStates {
 		STATE_NONE,
 		STATE_NON_AUTHENTICATED,
 		STATE_AUTHENTICATED,
@@ -75,28 +80,37 @@ public:
 	char hierarchySeparator() const;
 
 
-	void send(bool tag, const string& what, bool end);
-	void sendRaw(const char* buffer, const int count);
+	void sendCommand(const shared_ptr <IMAPCommand>& cmd);
+	void sendRaw(const byte_t* buffer, const size_t count);
 
 	IMAPParser::response* readResponse(IMAPParser::literalHandler* lh = NULL);
 
 
-	ref <const IMAPTag> getTag() const;
-	ref <const IMAPParser> getParser() const;
+	shared_ptr <const IMAPStore> getStore() const;
+	shared_ptr <IMAPStore> getStore();
 
-	ref <const IMAPStore> getStore() const;
-	ref <IMAPStore> getStore();
-
-	ref <session> getSession();
+	shared_ptr <session> getSession();
 
+	void fetchCapabilities();
+	void invalidateCapabilities();
 	const std::vector <string> getCapabilities();
+	bool hasCapability(const string& capa);
+	bool hasCapability(const string& capa) const;
 
-	ref <security::authenticator> getAuthenticator();
+	shared_ptr <security::authenticator> getAuthenticator();
 
 	bool isSecuredConnection() const;
-	ref <connectionInfos> getConnectionInfos() const;
+	shared_ptr <connectionInfos> getConnectionInfos() const;
 
-	ref <const socket> getSocket() const;
+	shared_ptr <const socket> getSocket() const;
+	void setSocket(const shared_ptr <socket>& sok);
+
+	shared_ptr <tracer> getTracer();
+
+	shared_ptr <IMAPTag> getTag();
+
+	bool isMODSEQDisabled() const;
+	void disableMODSEQ();
 
 private:
 
@@ -109,25 +123,37 @@ private:
 	void startTLS();
 #endif // VMIME_HAVE_TLS_SUPPORT
 
+	bool processCapabilityResponseData(const IMAPParser::response* resp);
+	void processCapabilityResponseData(const IMAPParser::capability_data* capaData);
 
-	weak_ref <IMAPStore> m_store;
 
-	ref <security::authenticator> m_auth;
+	weak_ptr <IMAPStore> m_store;
 
-	ref <socket> m_socket;
+	shared_ptr <security::authenticator> m_auth;
 
-	ref <IMAPParser> m_parser;
+	shared_ptr <socket> m_socket;
 
-	ref <IMAPTag> m_tag;
+	shared_ptr <IMAPParser> m_parser;
+
+	shared_ptr <IMAPTag> m_tag;
 
 	char m_hierarchySeparator;
 
 	ProtocolStates m_state;
 
-	ref <timeoutHandler> m_timeoutHandler;
+	shared_ptr <timeoutHandler> m_timeoutHandler;
 
 	bool m_secured;
-	ref <connectionInfos> m_cntInfos;
+	shared_ptr <connectionInfos> m_cntInfos;
+
+	bool m_firstTag;
+
+	std::vector <string> m_capabilities;
+	bool m_capabilitiesFetched;
+
+	bool m_noModSeq;
+
+	shared_ptr <tracer> m_tracer;
 
 
 	void internalDisconnect();
@@ -141,4 +167,6 @@ private:
 } // vmime
 
 
+#endif // VMIME_HAVE_MESSAGING_FEATURES && VMIME_HAVE_MESSAGING_PROTO_IMAP
+
 #endif // VMIME_NET_IMAP_IMAPCONNECTION_HPP_INCLUDED
