@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2013 Vincent Richard <vincent@vmime.org>
+// Copyright (C) 2002 Vincent Richard <vincent@vmime.org>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -47,9 +47,8 @@ class IMAPFolder;
 
 /** IMAP message implementation.
   */
+class VMIME_EXPORT IMAPMessage : public message {
 
-class VMIME_EXPORT IMAPMessage : public message
-{
 private:
 
 	friend class IMAPFolder;
@@ -59,8 +58,8 @@ private:
 
 public:
 
-	IMAPMessage(shared_ptr <IMAPFolder> folder, const size_t num);
-	IMAPMessage(shared_ptr <IMAPFolder> folder, const size_t num, const uid& uid);
+	IMAPMessage(const shared_ptr <IMAPFolder>& folder, const size_t num);
+	IMAPMessage(const shared_ptr <IMAPFolder>& folder, const size_t num, const uid& uid);
 
 	~IMAPMessage();
 
@@ -92,20 +91,24 @@ public:
 	int getFlags() const;
 	void setFlags(const int flags, const int mode = FLAG_MODE_SET);
 
-	void extract
-		(utility::outputStream& os,
-		 utility::progressListener* progress = NULL,
-		 const size_t start = 0, const size_t length = -1,
-		 const bool peek = false) const;
+	void extract(
+		utility::outputStream& os,
+		utility::progressListener* progress = NULL,
+		const size_t start = 0,
+		const size_t length = -1,
+		const bool peek = false
+	) const;
 
-	void extractPart
-		(shared_ptr <const messagePart> p,
-		 utility::outputStream& os,
-		 utility::progressListener* progress = NULL,
-		 const size_t start = 0, const size_t length = -1,
-		 const bool peek = false) const;
+	void extractPart(
+		const shared_ptr <const messagePart>& p,
+		utility::outputStream& os,
+		utility::progressListener* progress = NULL,
+		const size_t start = 0,
+		const size_t length = -1,
+		const bool peek = false
+	) const;
 
-	void fetchPartHeader(shared_ptr <messagePart> p);
+	void fetchPartHeader(const shared_ptr <messagePart>& p);
 
 	shared_ptr <vmime::message> getParsedMessage();
 
@@ -135,7 +138,7 @@ private:
 	  *
 	  * @param str structure for which to fetch parts headers
 	  */
-	void fetchPartHeaderForStructure(shared_ptr <messageStructure> str);
+	void fetchPartHeaderForStructure(const shared_ptr <messageStructure>& str);
 
 	/** Recursively contruct parsed message from structure.
 	  * Called by getParsedMessage().
@@ -144,7 +147,11 @@ private:
 	  * @param str structure for which to construct part
 	  * @param level current nesting level (0 is root)
 	  */
-	void constructParsedMessage(shared_ptr <bodyPart> parentPart, shared_ptr <messageStructure> str, int level = 0);
+	void constructParsedMessage(
+		const shared_ptr <bodyPart>& parentPart,
+		const shared_ptr <messageStructure>& str,
+		int level = 0
+	);
 
 
 	enum ExtractFlags
@@ -154,12 +161,14 @@ private:
 		EXTRACT_PEEK = 0x10
 	};
 
-	size_t extractImpl
-		(shared_ptr <const messagePart> p,
-		 utility::outputStream& os,
-		 utility::progressListener* progress,
-		 const size_t start, const size_t length,
-		 const int extractFlags) const;
+	size_t extractImpl(
+		const shared_ptr <const messagePart>& p,
+		utility::outputStream& os,
+		utility::progressListener* progress,
+		const size_t start,
+		const size_t length,
+		const int extractFlags
+	) const;
 
 
 	shared_ptr <header> getOrCreateHeader();
