@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2009 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002 Vincent Richard <vincent@vmime.org>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -25,6 +25,12 @@
 #define VMIME_NET_IMAP_IMAPTAG_HPP_INCLUDED
 
 
+#include "vmime/config.hpp"
+
+
+#if VMIME_HAVE_MESSAGING_FEATURES && VMIME_HAVE_MESSAGING_PROTO_IMAP
+
+
 #include "vmime/types.hpp"
 
 
@@ -33,8 +39,8 @@ namespace net {
 namespace imap {
 
 
-class IMAPTag : public object
-{
+class VMIME_EXPORT IMAPTag : public object {
+
 private:
 
 	IMAPTag(const int number);
@@ -47,6 +53,7 @@ public:
 	IMAPTag& operator++();           // ++IMAPTag
 	const IMAPTag operator++(int);   // IMAPTag++
 
+	int maximumNumber() const;
 	int number() const;
 
 	operator string() const;
@@ -67,4 +74,6 @@ private:
 } // vmime
 
 
+#endif // VMIME_HAVE_MESSAGING_FEATURES && VMIME_HAVE_MESSAGING_PROTO_IMAP
+
 #endif // VMIME_NET_IMAP_IMAPTAG_HPP_INCLUDED
