@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2009 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002 Vincent Richard <vincent@vmime.org>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -25,11 +25,20 @@
 #define VMIME_NET_IMAP_IMAPUTILS_HPP_INCLUDED
 
 
+#include "vmime/config.hpp"
+
+
+#if VMIME_HAVE_MESSAGING_FEATURES && VMIME_HAVE_MESSAGING_PROTO_IMAP
+
+
 #include "vmime/types.hpp"
 #include "vmime/dateTime.hpp"
 
 #include "vmime/net/folder.hpp"
+#include "vmime/net/message.hpp"
 #include "vmime/net/imap/IMAPParser.hpp"
+#include "vmime/net/imap/IMAPConnection.hpp"
+#include "vmime/net/imap/IMAPCommand.hpp"
 
 #include "vmime/mailboxList.hpp"
 
@@ -41,7 +50,7 @@ namespace net {
 namespace imap {
 
 
-class IMAPUtils
+class VMIME_EXPORT IMAPUtils
 {
 public:
 
@@ -58,28 +67,20 @@ public:
 	  */
 	static const string quoteString(const string& text);
 
-	static int folderTypeFromFlags(const IMAPParser::mailbox_flag_list* list);
-	static int folderFlagsFromFlags(const IMAPParser::mailbox_flag_list* list);
+	/** Parse mailbox flags and fill in folder attributes.
+	  *
+	  * @param cnt reference to current IMAP connection (for testing capabilities)
+	  * @param list list of mailbox flags
+	  * @param attribs reference to an object holding folder attributes
+	  */
+	static void mailboxFlagsToFolderAttributes
+		(const shared_ptr <const IMAPConnection>& cnt,
+		 const IMAPParser::mailbox_flag_list* list,
+		 folderAttributes& attribs);
 
 	static int messageFlagsFromFlags(const IMAPParser::flag_list* list);
 
-	static const string messageFlagList(const int flags);
-
-	/** Build an "IMAP set" given a list. The function tries to group
-	  * consecutive message numbers to reduce the list.
-	  *
-	  * Example:
-	  *    IN  = "1,2,3,4,5,7,8,13,15,16,17"
-	  *    OUT = "1:5,7:8,13,15:*" for a mailbox with a total of 17 messages (max = 17)
-	  *
-	  * @param list list of message numbers
-	  * @param max number of messages in the mailbox (or -1 if not known)
-	  * @param alreadySorted set to true if the list of message numbers is
-	  * already sorted in ascending order
-	  * @return a set corresponding to the message list
-	  */
-	static const string listToSet(const std::vector <int>& list,
-		const int max = -1, const bool alreadySorted = false);
+	static const std::vector <string> messageFlagList(const int flags);
 
 	/** Format a date/time to IMAP date/time format.
 	  *
@@ -88,13 +89,16 @@ public:
 	  */
 	static const string dateTime(const vmime::datetime& date);
 
-	/** Construct a fetch request for the specified messages.
+	/** Construct a fetch request for the specified messages, designated
+	  * either by their sequence numbers or their UIDs.
 	  *
-	  * @param list list of message numbers
+	  * @param cnt connection
+	  * @param msgs message set
 	  * @param options fetch options
 	  * @return fetch request
 	  */
-	static const string buildFetchRequest(const std::vector <int>& list, const int options);
+	static shared_ptr <IMAPCommand> buildFetchCommand
+		(const shared_ptr <IMAPConnection>& cnt, const messageSet& msgs, const fetchAttributes& options);
 
 	/** Convert a parser-style address list to a mailbox list.
 	  *
@@ -102,6 +106,25 @@ public:
 	  * @param dest output mailbox list
 	  */
 	static void convertAddressList(const IMAPParser::address_list& src, mailboxList& dest);
+
+	/** Returns an IMAP-formatted sequence set given a message set.
+	  *
+	  * @param msgs message set
+	  * @return IMAP sequence set (eg. "1:5,7,15:*")
+	  */
+	static const string messageSetToSequenceSet(const messageSet& msgs);
+
+	/** Constructs a message set from a parser 'uid_set' structure.
+	  *
+	  * @param uidSet UID set, as returned by the parser
+	  * @return message set
+	  */
+	static messageSet buildMessageSet(const IMAPParser::uid_set* uidSet);
+
+private:
+
+	static const string buildFetchRequestImpl
+		(const shared_ptr <IMAPConnection>& cnt, const string& mode, const string& set, const int options);
 };
 
 
@@ -110,4 +133,6 @@ public:
 } // vmime
 
 
+#endif // VMIME_HAVE_MESSAGING_FEATURES && VMIME_HAVE_MESSAGING_PROTO_IMAP
+
 #endif // VMIME_NET_IMAP_IMAPUTILS_HPP_INCLUDED
