@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2009 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002 Vincent Richard <vincent@vmime.org>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -26,6 +26,11 @@
 
 
 #include "vmime/config.hpp"
+
+
+#if VMIME_HAVE_MESSAGING_FEATURES && VMIME_HAVE_MESSAGING_PROTO_POP3
+
+
 #include "vmime/net/serviceInfos.hpp"
 
 
@@ -36,15 +41,13 @@ namespace pop3 {
 
 /** Information about POP3 service.
   */
+class VMIME_EXPORT POP3ServiceInfos : public serviceInfos {
 
-class POP3ServiceInfos : public serviceInfos
-{
 public:
 
 	POP3ServiceInfos(const bool pop3s);
 
-	struct props
-	{
+	struct props {
 		// POP3-specific options
 		serviceInfos::property PROPERTY_OPTIONS_APOP;
 		serviceInfos::property PROPERTY_OPTIONS_APOP_FALLBACK;
@@ -82,5 +85,7 @@ private:
 } // vmime
 
 
+#endif // VMIME_HAVE_MESSAGING_FEATURES && VMIME_HAVE_MESSAGING_PROTO_POP3
+
 #endif // VMIME_NET_POP3_POP3SERVICEINFOS_HPP_INCLUDED
 
