@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2009 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002 Vincent Richard <vincent@vmime.org>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -27,11 +27,16 @@
 
 #include "vmime/config.hpp"
 
+
+#if VMIME_HAVE_MESSAGING_FEATURES && VMIME_HAVE_MESSAGING_PROTO_SMTP
+
+
 #include "vmime/net/transport.hpp"
 #include "vmime/net/socket.hpp"
 #include "vmime/net/timeoutHandler.hpp"
 
 #include "vmime/net/smtp/SMTPServiceInfos.hpp"
+#include "vmime/net/smtp/SMTPConnection.hpp"
 
 
 namespace vmime {
@@ -39,17 +44,21 @@ namespace net {
 namespace smtp {
 
 
-class SMTPResponse;
+class SMTPCommand;
 
 
 /** SMTP transport service.
   */
+class VMIME_EXPORT SMTPTransport : public transport {
 
-class SMTPTransport : public transport
-{
 public:
 
-	SMTPTransport(ref <session> sess, ref <security::authenticator> auth, const bool secured = false);
+	SMTPTransport(
+		const shared_ptr <session>& sess,
+		const shared_ptr <security::authenticator>& auth,
+		const bool secured = false
+	);
+
 	~SMTPTransport();
 
 	const string getProtocolName() const;
@@ -63,41 +72,58 @@ public:
 
 	void noop();
 
-	void send(const mailbox& expeditor, const mailboxList& recipients, utility::inputStream& is, const utility::stream::size_type size, utility::progressListener* progress = NULL);
+	void send(
+		const mailbox& expeditor,
+		const mailboxList& recipients,
+		utility::inputStream& is,
+		const size_t size,
+		utility::progressListener* progress = NULL,
+		const mailbox& sender = mailbox()
+	);
+
+	void send(
+		const shared_ptr <vmime::message>& msg,
+		const mailbox& expeditor,
+		const mailboxList& recipients,
+		utility::progressListener* progress = NULL,
+		const mailbox& sender = mailbox()
+	);
 
 	bool isSecuredConnection() const;
-	ref <connectionInfos> getConnectionInfos() const;
+	shared_ptr <connectionInfos> getConnectionInfos() const;
+	shared_ptr <SMTPConnection> getConnection();
+
+	bool isSMTPS() const;
 
 private:
 
-	void sendRequest(const string& buffer, const bool end = true);
-	ref <SMTPResponse> readResponse();
+	static bool mailboxNeedsUTF8(const mailbox& mb);
 
-	void internalDisconnect();
+	/** Send the MAIL and RCPT commands to the server, checking the
+	  * response, and using pipelining if supported by the server.
+	  * Optionally, the DATA command can also be sent.
+	  *
+	  * @param expeditor expeditor mailbox
+	  * @param recipients list of recipient mailboxes
+	  * @param sender envelope sender (if empty, expeditor will be used)
+	  * @param sendDATACommand if true, the DATA command will be sent
+	  * @param size message size, in bytes (or 0, if not known)
+	  */
+	void sendEnvelope(
+		const mailbox& expeditor,
+		const mailboxList& recipients,
+		const mailbox& sender,
+		bool sendDATACommand,
+		const size_t size
+	);
 
-	void helo();
-	void authenticate();
-#if VMIME_HAVE_SASL_SUPPORT
-	void authenticateSASL();
-#endif // VMIME_HAVE_SASL_SUPPORT
 
-#if VMIME_HAVE_TLS_SUPPORT
-	void startTLS();
-#endif // VMIME_HAVE_TLS_SUPPORT
+	shared_ptr <SMTPConnection> m_connection;
 
-	ref <socket> m_socket;
-	bool m_authentified;
-
-	bool m_extendedSMTP;
-	std::map <string, std::vector <string> > m_extensions;
-
-	ref <timeoutHandler> m_timeoutHandler;
 
 	const bool m_isSMTPS;
 
-	bool m_secured;
-	ref <connectionInfos> m_cntInfos;
-
+	bool m_needReset;
 
 	// Service infos
 	static SMTPServiceInfos sm_infos;
@@ -109,4 +135,6 @@ private:
 } // vmime
 
 
+#endif // VMIME_HAVE_MESSAGING_FEATURES && VMIME_HAVE_MESSAGING_PROTO_SMTP
+
 #endif // VMIME_NET_SMTP_SMTPTRANSPORT_HPP_INCLUDED
