@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2009 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002 Vincent Richard <vincent@vmime.org>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -34,23 +34,23 @@ namespace digest {
 namespace sha1 {
 
 
-class sha1MessageDigest : public messageDigest
-{
+class sha1MessageDigest : public messageDigest {
+
 public:
 
 	sha1MessageDigest();
 
 	void update(const byte_t b);
 	void update(const string& s);
-	void update(const byte_t* buffer, const unsigned long len);
-	void update(const byte_t* buffer, const unsigned long offset, const unsigned long len);
+	void update(const byte_t* buffer, const size_t len);
+	void update(const byte_t* buffer, const size_t offset, const size_t len);
 
 	void finalize();
 	void finalize(const string& s);
-	void finalize(const byte_t* buffer, const unsigned long len);
-	void finalize(const byte_t* buffer, const unsigned long offset, const unsigned long len);
+	void finalize(const byte_t* buffer, const size_t len);
+	void finalize(const byte_t* buffer, const size_t offset, const size_t len);
 
-	int getDigestLength() const;
+	size_t getDigestLength() const;
 	const byte_t* getDigest() const;
 
 	void reset();
