@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2013 Vincent Richard <vincent@vmime.org>
+// Copyright (C) 2002 Vincent Richard <vincent@vmime.org>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -36,12 +36,10 @@ namespace vmime {
 namespace utility {
 
 
-
 /** Base class for input/output stream.
   */
+class VMIME_EXPORT stream : public object, private noncopyable {
 
-class VMIME_EXPORT stream : public object, private noncopyable
-{
 public:
 
 	virtual ~stream() { }
