@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2009 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002 Vincent Richard <vincent@vmime.org>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -35,9 +35,8 @@ namespace utility {
 
 /** Miscellaneous functions related to URLs.
   */
+class VMIME_EXPORT urlUtils {
 
-class urlUtils
-{
 public:
 
 	/** Encode extended characters in a URL string (ASCII characters
