@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2009 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002 Vincent Richard <vincent@vmime.org>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -27,27 +27,51 @@
 
 #include "vmime/headerFieldValue.hpp"
 #include "vmime/charset.hpp"
+#include "vmime/charsetConverterOptions.hpp"
 
 
-namespace vmime
-{
+namespace vmime {
 
 
 /** A class that encapsulates an encoded-word (RFC-2047):
   * some text encoded into one specified charset.
   */
+class VMIME_EXPORT word : public headerFieldValue {
 
-class word : public headerFieldValue
-{
 	friend class text;
 
 public:
 
+	/** Construct an empty word.
+	  * Charset is set to the current locale charset.
+	  */
 	word();
+
+	/** Construct a word by copying another word.
+	  */
 	word(const word& w);
-	word(const string& buffer); // Defaults to locale charset
+
+	/** Construct a word using a string buffer.
+	  * Charset is set to the current locale charset.
+	  */
+	explicit word(const string& buffer);
+
+	/** Construct a word using a string buffer and a specified charset.
+	  *
+	  * @param buffer string buffer
+	  * @param charset charset in which the string is encoded
+	  */
 	word(const string& buffer, const charset& charset);
 
+	/** Construct a word using a string buffer and a specified charset
+	  * and language tag (RFC-1766).
+	  *
+	  * @param buffer string buffer
+	  * @param charset charset in which the string is encoded
+	  * @param lang language tag, in the format specified by RFC-1766
+	  */
+	word(const string& buffer, const charset& charset, const string& lang);
+
 	/** Return the raw data for this encoded word.
 	  *
 	  * @return raw data buffer
@@ -84,6 +108,28 @@ public:
 	  */
 	void setCharset(const charset& ch);
 
+	/** Return the language used in this word (optional).
+	  * If not specified, the value is empty.
+	  *
+	  * @return language tag for this word, in the format specified
+	  * by RFC-1766
+	  */
+	const string getLanguage() const;
+
+	/** Set the language used in this word (optional).
+	  *
+	  * @param lang language tag, in the format specified by RFC-1766
+	  */
+	void setLanguage(const string& lang);
+
+	/** Returns whether two words actually represent the same text,
+	  * regardless of their charset.
+	  *
+	  * @param other word to compare to
+	  * @return true if the two words represent the same text, or false otherwise
+	  */
+	bool isEquivalent(const word& other) const;
+
 
 	word& operator=(const word& w);
 	word& operator=(const string& s);
@@ -94,9 +140,13 @@ public:
 	/** Return the contained text converted to the specified charset.
 	  *
 	  * @param dest output charset
+	  * @param opts options for charset conversion
 	  * @return word converted to the specified charset
 	  */
-	const string getConvertedText(const charset& dest) const;
+	const string getConvertedText(
+		const charset& dest,
+		const charsetConverterOptions& opts = charsetConverterOptions()
+	) const;
 
 	/** Replace data in this word by data in other word.
 	  *
@@ -108,47 +158,111 @@ public:
 	  *
 	  * @return a copy of this word
 	  */
-	ref <component> clone() const;
+	shared_ptr <component> clone() const;
 
 
 #ifndef VMIME_BUILDING_DOC
-	class generatorState
-	{
+	class generatorState {
+
 	public:
 
 		generatorState()
-			: isFirstWord(true), prevWordIsEncoded(false), lastCharIsSpace(false)
-		{
+			: isFirstWord(true),
+			  prevWordIsEncoded(false),
+			  lastCharIsSpace(false) {
+
 		}
 
 		bool isFirstWord;
 		bool prevWordIsEncoded;
 		bool lastCharIsSpace;
 	};
+
+	class parserState {
+
+	public:
+
+		parserState()
+			: prevIsEncoded(false),
+			  isFirst(true) {
+
+		}
+
+		bool prevIsEncoded;
+		bool isFirst;
+		std::string undecodedBytes;
+	};
 #endif
 
 
-	using component::parse;
+protected:
+
+	void parseImpl(
+		const parsingContext& ctx,
+		const string& buffer,
+		const size_t position,
+		const size_t end,
+		size_t* newPosition = NULL
+	);
+
+	void generateImpl(
+		const generationContext& ctx,
+		utility::outputStream& os,
+		const size_t curLinePos = 0,
+		size_t* newLinePos = NULL
+	) const;
+
+	void parseWithState(
+		const parsingContext& ctx,
+		const string& buffer,
+		const size_t position,
+		const size_t end,
+		size_t* newPosition,
+		parserState* state
+	);
+
+public:
+
 	using component::generate;
 
-	void parse(const string& buffer, const string::size_type position, const string::size_type end, string::size_type* newPosition = NULL);
-	void generate(utility::outputStream& os, const string::size_type maxLineLength = lineLengthLimits::infinite, const string::size_type curLinePos = 0, string::size_type* newLinePos = NULL) const;
+#ifndef VMIME_BUILDING_DOC
+	void generate(
+		const generationContext& ctx,
+		utility::outputStream& os,
+		const size_t curLinePos,
+		size_t* newLinePos,
+		const int flags,
+		generatorState* state
+	) const;
+#endif
 
-	void generate(utility::outputStream& os, const string::size_type maxLineLength, const string::size_type curLinePos, string::size_type* newLinePos, const int flags, generatorState* state) const;
-
-	const std::vector <ref <const component> > getChildComponents() const;
+	const std::vector <shared_ptr <component> > getChildComponents();
 
 private:
 
-	static ref <word> parseNext(const string& buffer, const string::size_type position, const string::size_type end, string::size_type* newPosition, bool prevIsEncoded, bool* isEncoded, bool isFirst);
+	static shared_ptr <word> parseNext(
+		const parsingContext& ctx,
+		const string& buffer,
+		const size_t position,
+		const size_t end,
+		size_t* newPosition,
+		parserState* state
+	);
 
-	static const std::vector <ref <word> > parseMultiple(const string& buffer, const string::size_type position, const string::size_type end, string::size_type* newPosition);
+	static const std::vector <shared_ptr <word> > parseMultiple(
+		const parsingContext& ctx,
+		const string& buffer,
+		const size_t position,
+		const size_t end,
+		size_t* newPosition
+	);
 
 
 	// The "m_buffer" of this word holds the data, and this data is encoded
 	// in the specified "m_charset".
 	string m_buffer;
 	charset m_charset;
+	string m_lang;
 };
 
 
